@@ -1,6 +1,6 @@
 #! /usr/bin/env bash
 #
-# Copyright (c) 2013-2016 Commonwealth Computer Research, Inc.
+# Copyright (c) 2013-2019 Commonwealth Computer Research, Inc.
 # All rights reserved. This program and the accompanying materials
 # are made available under the terms of the Apache License, Version 2.0 which
 # accompanies this distribution and is available at
@@ -19,14 +19,14 @@ fi
 
 install_dir="${1:-${GEOMESA_BIGTABLE_HOME}/lib}"
 
-osgeo_url="${GEOMESA_MAVEN_URL:-http://download.osgeo.org/webdav/}"
+osgeo_url="${GEOMESA_MAVEN_URL:-https://repo.osgeo.org/repository/release/}"
 mvn_url="${GEOMESA_MAVEN_URL:-https://search.maven.org/remotecontent?filepath=}"
 
 declare -a urls=(
   "${mvn_url}org/jaitools/jt-utils/${jt_version}/jt-utils-${jt_version}.jar"
-  "${osgeo_url}geotools/javax/media/jai_codec/${jai_version}/jai_codec-${jai_version}.jar"
-  "${osgeo_url}geotools/javax/media/jai_core/${jai_version}/jai_core-${jai_version}.jar"
-  "${osgeo_url}geotools/javax/media/jai_imageio/${imageio_version}/jai_imageio-${imageio_version}.jar"
+  "${osgeo_url}/javax/media/jai_codec/${jai_version}/jai_codec-${jai_version}.jar"
+  "${osgeo_url}/javax/media/jai_core/${jai_version}/jai_core-${jai_version}.jar"
+  "${osgeo_url}/javax/media/jai_imageio/${imageio_version}/jai_imageio-${imageio_version}.jar"
 )
 
 echo "Warning: Java Advanced Imaging (JAI) is LGPL licensed, and thus not distributed with GeoMesa. However, you may download it yourself."
